@@ -1,4 +1,4 @@
-# -*- encoding: ascii -*-
+# -*- coding: ascii -*-
 """
 Benchmarks
 ~~~~~~~~~~
@@ -20,16 +20,16 @@ def tox(ctx, rebuild=False, env=None):
       `env` : ``str``
         Run this one environment only.
     """
-    tox = ctx.shell.frompath('tox')  # pylint: disable = redefined-outer-name
+    tox = ctx.shell.frompath("tox")  # pylint: disable = redefined-outer-name
     if tox is None:
         raise RuntimeError("tox not found")
 
-    command = r''' %s -c bench/tox.ini '''
+    command = r""" %s -c bench/tox.ini """
     args = [tox]
     if rebuild:
-        command += ' -r'
+        command += " -r"
     if env is not None:
-        command += ' -e %s'
+        command += " -e %s"
         args.append(env)
 
     with ctx.shell.root_dir():
